﻿using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Telerik.Charting;
using Telerik.UI.Xaml.Controls.Chart;

namespace ObservableChartView
{
    public sealed partial class MainPage : Page
    {
        private MainViewModel viewModel;

        public MainPage()
        {
            this.InitializeComponent();
            viewModel = this.DataContext as MainViewModel;

            Loaded += MainPage_Loaded;
        }

        private void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            //STEP ONE - instantiate and configure the RadCatesianChart
            var chart = new RadCartesianChart();

            //define the axes
            chart.HorizontalAxis = new DateTimeCategoricalAxis { LabelFitMode = AxisLabelFitMode.Rotate};
            chart.VerticalAxis = new LinearAxis();


            //STEP TWO - Instaitate and configure a series
            //instantiate and configure a series
            var lineSeries = new LineSeries();

            //set the items source 
            //(NOTE - because SensorDataPoints is an ObservableCollection, and is using OnPropertychanged in the setter, you only need to set this once)
            lineSeries.ItemsSource = viewModel.SensorDataPoints;

            //configure the value and category bindings
            lineSeries.ValueBinding = new PropertyNameDataPointBinding("ReadingValue");
            lineSeries.CategoryBinding = new PropertyNameDataPointBinding("ReadingTimestamp");

            //STEP THREE - Add the series to the CartesianChart
            chart.Series.Add(lineSeries);

            //FINAL STEP - Add the Chart to the VisualTree
            this.RootGrid.Children.Add(chart);
        }

        private void UpdateDataPointsButton_OnClick(object sender, RoutedEventArgs e)
        {
            //This approach clears and adds data points to the SAME collection
            viewModel.UpdateSensorDataPoints();
        }

        private void ReplaceDataPointsButton_OnClick(object sender, RoutedEventArgs e)
        {
            //this approach replaces the Collection
            viewModel.SensorDataPoints = viewModel.GetSensorDataPoints();
        }
    }
}
