﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using ObservableChartView.Annotations;

namespace ObservableChartView
{
    public class MainViewModel :INotifyPropertyChanged
    {
        private int valueIncrementer;

        public MainViewModel()
        {
            //get the first set of points to show when the app launches
            SensorDataPoints = GetSensorDataPoints();
        }

        private ObservableCollection<SensorDataPoint> sensorDataPoints;
        public ObservableCollection<SensorDataPoint> SensorDataPoints
        {
            get { return sensorDataPoints; }
            set { sensorDataPoints = value; OnPropertyChanged();}
        }
        
        /// <summary>
        /// this method will clear the current collection of datapoints and add new ones
        /// </summary>
        public void UpdateSensorDataPoints()
        {
            //this clears the current list
            this.SensorDataPoints.Clear();
            
            for (int i = 1; i < 21; i++)
            {
                this.SensorDataPoints.Add(new SensorDataPoint()
                {
                    ReadingValue = i + valueIncrementer++,
                    ReadingTimestamp = DateTime.Now.AddDays(-i)
                });
            }
        }

        /// <summary>
        /// This method will return a new collection of data points
        /// </summary>
        /// <returns></returns>
        public ObservableCollection<SensorDataPoint> GetSensorDataPoints()
        {
            //new-up a collection
            var newListOfPoints = new ObservableCollection<SensorDataPoint>();
            
            for (int i = 1; i < 21; i++)
            {
                newListOfPoints.Add(new SensorDataPoint()
                {
                    ReadingValue = i + valueIncrementer++,
                    ReadingTimestamp = DateTime.Now.AddDays(-i)
                });
            }

            return newListOfPoints;
        }
        

        #region INPC
        public event PropertyChangedEventHandler PropertyChanged;

        [NotifyPropertyChangedInvocator]
        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion
    }
}
